@@ -26,6 +26,14 @@
 #define TRADER_API_DLL_EXPORT 
 #endif
 
+// ѯӦ
+#define QRY_ERROR_NONE 0
+#define QRY_ERROR_INVALID_LOGIN -1
+#define QRY_ERROR_DUPLICATE_LOGIN 2
+#define QRY_ERROR_NOT_LOGIN_YET -3
+#define QRY_ERROR_NO_PRIVILEGE -4 	// ޴Ȩޣǹδ
+#define QRY_ERROR_REQUEST -6		// ѯ󣺲ѯ죬δɵĲѯ
+
 class CThostFtdcTraderSpi
 {
 public:
@@ -34,17 +42,25 @@ public:
 	
 	///ͻ뽻׺̨ͨӶϿʱ÷áAPIԶӣͻ˿ɲ
 	///@param nReason ԭ
-	///        0x1001 ʧ
-	///        0x1002 дʧ
-	///        0x2001 ʱ
-	///        0x2002 ʧ
-	///        0x2003 յ
+	///        -3	ر
+	///        -4	ʧ
+	///        -5	дʧ
+	///        -6	ˮ
+	///        -7	кŴ
+	///        -8	
+	///        -9	С
 	virtual void OnFrontDisconnected(int nReason){};
 		
 	///ʱ档ʱδյʱ÷á
 	///@param nTimeLapse ϴνձĵʱ
 	virtual void OnHeartBeatWarning(int nTimeLapse){};
 	
+	///ؾӦ
+	virtual void OnRspSubscribeFlowCtrlWarning(CThostFtdcSpecificTraderField *pRspSubscribeTraderField, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
+	///ȡؾӦ
+	virtual void OnRspUnSubscribeFlowCtrlWarning(CThostFtdcSpecificTraderField *pRspSubscribeTraderField, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
 	///ͻ֤Ӧ
 	virtual void OnRspAuthenticate(CThostFtdcRspAuthenticateField *pRspAuthenticateField, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 	
@@ -61,6 +77,9 @@ public:
 	///Ӧ
 	virtual void OnRspOrderAction(CThostFtdcInputOrderActionField *pInputOrderAction, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
+	///Ӧ
+	virtual void OnRspMKBatchOrderAction(CThostFtdcMKInputOrderActionField *pMKInputOrderAction, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
 	///ִ¼Ӧ
 	virtual void OnRspExecOrderInsert(CThostFtdcInputExecOrderField *pInputExecOrder, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
@@ -139,9 +158,6 @@ public:
 	///ѯͶֲ߳ϸӦ
 	virtual void OnRspQryInvestorPositionDetail(CThostFtdcInvestorPositionDetailField *pInvestorPositionDetail, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
-	///ѯͶֲ߳ϸӦ
-	virtual void OnRspQryInvestorPositionCombineDetail(CThostFtdcInvestorPositionCombineDetailField *pInvestorPositionCombineDetail, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
-
 	///ѯ֤Ӧ
 	virtual void OnRspQryExchangeMarginRate(CThostFtdcExchangeMarginRateField *pExchangeMarginRate, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
@@ -163,6 +179,12 @@ public:
 	///ѯѯۼ۲Ӧ
 	virtual void OnRspQryForQuoteParam(CThostFtdcForQuoteParamField *pForQuoteParam, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
+	///ѯͶSPBMƷϸӦ
+	virtual void OnRspQryInvestorProdSPBMDetail(CThostFtdcInvestorProdSPBMDetailField *pInvestorProdSPBMDetail, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
+	///ѯԱ̻Ӧ
+	virtual void OnRspQryTraderOffer(CThostFtdcTraderOfferField *pTraderOffer, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
+
 	///ѯӦ
 	virtual void OnRspQryQuote(CThostFtdcQuoteField *pQuote, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
@@ -229,6 +251,8 @@ public:
 	///ѯ걨Ӧ
 	virtual void OnRspQryInstrumentOrderCommRate(CThostFtdcInstrumentOrderCommRateField *pInstrumentOrderCommRate, CThostFtdcRspInfoField *pRspInfo, int nRequestID, bool bIsLast) {};
 
+	///ϯλؾ
+	virtual void OnRtnFlowCtrlWarning(CThostFtdcFlowCtrlWarningField *pFlowCtrlWarning) {};
 };
 
 class TRADER_API_DLL_EXPORT CThostFtdcTraderApi
@@ -287,6 +311,14 @@ public:
 	///@remark ÷ҪInitǰá򲻻յݡ
 	virtual void SubscribePublicTopic(THOST_TE_RESUME_TYPE nResumeType) = 0;
 
+	///Ľؾ
+	///@remark ÷ڵ¼ɹ֮á
+	virtual int SubscribeFlowCtrlWarning(char *ppTraderID[], int nCount) = 0;
+
+	///ȡĽؾ
+	///@remark ÷ڵ¼ɹ֮á
+	virtual int UnSubscribeFlowCtrlWarning(char *ppTraderID[], int nCount) = 0;
+
 	///ͻ֤
 	virtual int ReqAuthenticate(CThostFtdcReqAuthenticateField *pReqAuthenticateField, int nRequestID) = 0 ;
 
@@ -305,6 +337,9 @@ public:
 	///
 	virtual int ReqOrderAction(CThostFtdcInputOrderActionField *pInputOrderAction, int nRequestID) = 0;
 
+	///
+	virtual int ReqMKBatchOrderAction(CThostFtdcMKInputOrderActionField *pMKInputOrderAction, int nRequestID) = 0;
+
 	///ִ¼
 	virtual int ReqExecOrderInsert(CThostFtdcInputExecOrderField *pInputExecOrder, int nRequestID) = 0;
 
@@ -387,10 +422,6 @@ public:
 	///ֲϸάԲѯΪ׼
 	virtual int ReqQryInvestorPositionDetail(CThostFtdcQryInvestorPositionDetailField *pQryInvestorPositionDetail, int nRequestID) = 0;
 
-	///ѯͶϳֲϸ
-	///ϳֲϸάԲѯΪ׼
-	virtual int ReqQryInvestorPositionCombineDetail(CThostFtdcQryInvestorPositionCombineDetailField *pQryInvestorPositionCombineDetail, int nRequestID) = 0;
-
 	///ѯ֤
 	virtual int ReqQryExchangeMarginRate(CThostFtdcQryExchangeMarginRateField *pQryExchangeMarginRate, int nRequestID) = 0;
 
@@ -418,6 +449,13 @@ public:
 	///ѯѯۼ۲
 	virtual int ReqQryForQuoteParam(CThostFtdcQryForQuoteParamField *pQryForQuoteParam, int nRequestID) = 0;
 
+	///ѯԱ̻
+	virtual int ReqQryTraderOffer(CThostFtdcQryTraderOfferField *pQryTraderOffer, int nRequestID) = 0;
+	
+	///ѯͶSPBMƷϸ
+	virtual int ReqQryInvestorProdSPBMDetail(CThostFtdcQryInvestorProdSPBMDetailField *pQryInvestorProdSPBMDetail, int nRequestID) = 0;
+	
+
 protected:
 	~CThostFtdcTraderApi(){};
 };
