@@ -117,6 +117,11 @@ THOST_FTDC_OSS_Accepted = '3'
 THOST_FTDC_OSS_InsertRejected = '4'
 THOST_FTDC_OSS_CancelRejected = '5'
 THOST_FTDC_OSS_ModifyRejected = '6'
+THOST_FTDC_RS_Submitted = 'a'
+THOST_FTDC_RS_Canceled = 'c'
+THOST_FTDC_RS_DELETE = '0'
+THOST_FTDC_RS_HANGUP = '1'
+THOST_FTDC_RS_ACTIVATE = '2'
 THOST_FTDC_PSD_Today = '1'
 THOST_FTDC_PSD_History = '2'
 THOST_FTDC_PDT_UseHistory = '1'
@@ -130,6 +135,7 @@ THOST_FTDC_PC_Combination = '3'
 THOST_FTDC_PC_Spot = '4'
 THOST_FTDC_PC_EFP = '5'
 THOST_FTDC_PC_SpotOption = '6'
+THOST_FTDC_PC_TAS = '7'
 THOST_FTDC_IP_NotStart = '0'
 THOST_FTDC_IP_Started = '1'
 THOST_FTDC_IP_Pause = '2'
@@ -152,6 +158,8 @@ THOST_FTDC_HF_Speculation = '1'
 THOST_FTDC_HF_Arbitrage = '2'
 THOST_FTDC_HF_Hedge = '3'
 THOST_FTDC_HF_MarketMaker = '5'
+THOST_FTDC_HF_SpecHedge = '6'
+THOST_FTDC_HF_HedgeSpec = '7'
 THOST_FTDC_BHF_Speculation = '1'
 THOST_FTDC_BHF_Arbitrage = '2'
 THOST_FTDC_BHF_Hedge = '3'
@@ -223,6 +231,8 @@ THOST_FTDC_CC_BidPriceLesserThanStopPrice = 'F'
 THOST_FTDC_CC_BidPriceLesserEqualStopPrice = 'H'
 THOST_FTDC_AF_Delete = '0'
 THOST_FTDC_AF_Modify = '3'
+THOST_FTDC_MKAM_Product = '1'
+THOST_FTDC_MKAM_OrderRef = '2'
 THOST_FTDC_TR_Allow = '0'
 THOST_FTDC_TR_CloseOnly = '1'
 THOST_FTDC_TR_Forbidden = '2'
@@ -1114,6 +1124,27 @@ THOST_FTDC_COMBT_STD = '3'
 THOST_FTDC_COMBT_STG = '4'
 THOST_FTDC_COMBT_PRT = '5'
 THOST_FTDC_COMBT_CLD = '6'
+THOST_FTDC_DCECOMBT_SPL = '0'
+THOST_FTDC_DCECOMBT_OPL = '1'
+THOST_FTDC_DCECOMBT_SP = '2'
+THOST_FTDC_DCECOMBT_SPC = '3'
+THOST_FTDC_DCECOMBT_BLS = '4'
+THOST_FTDC_DCECOMBT_BES = '5'
+THOST_FTDC_DCECOMBT_CAS = '6'
+THOST_FTDC_DCECOMBT_STD = '7'
+THOST_FTDC_DCECOMBT_STG = '8'
+THOST_FTDC_DCECOMBT_BFO = '9'
+THOST_FTDC_DCECOMBT_SFO = 'a'
+THOST_FTDC_CZCECOMBT_SPZ = '0'
+THOST_FTDC_CZCECOMBT_SPD = '1'
+THOST_FTDC_CZCECOMBT_IPS = '2'
+THOST_FTDC_CZCECOMBT_BUL = '3'
+THOST_FTDC_CZCECOMBT_BER = '4'
+THOST_FTDC_CZCECOMBT_BLT = '5'
+THOST_FTDC_CZCECOMBT_BRT = '6'
+THOST_FTDC_CZCECOMBT_STD = '7'
+THOST_FTDC_CZCECOMBT_STG = '8'
+THOST_FTDC_CZCECOMBT_PRT = '9'
 THOST_FTDC_ORPT_PreSettlementPrice = '1'
 THOST_FTDC_ORPT_OpenPrice = '4'
 THOST_FTDC_BLAG_Default = '1'
@@ -1157,6 +1188,9 @@ THOST_FTDC_CFUFN_SUFN_F = 'F'
 THOST_FTDC_CFUFN_SUFN_S = 'S'
 THOST_FTDC_CMDR_Comb = '0'
 THOST_FTDC_CMDR_UnComb = '1'
+THOST_FTDC_CMDR_DelComb = '2'
+THOST_FTDC_CONFREQ_ARBI = '1'
+THOST_FTDC_CONFREQ_HEDGE = '2'
 THOST_FTDC_STOV_RealValue = '1'
 THOST_FTDC_STOV_ProfitValue = '2'
 THOST_FTDC_STOV_RealRatio = '3'
@@ -1168,3 +1202,4 @@ THOST_FTDC_ROAST_Invalid = '3'
 THOST_FTDC_OSCF_CloseSelfOptionPosition = '1'
 THOST_FTDC_OSCF_ReserveOptionPosition = '2'
 THOST_FTDC_OSCF_SellCloseSelfFuturePosition = '3'
+THOST_FTDC_OSCF_ReserveFuturePosition = '4'
