@@ -1,7 +1,7 @@
 from pathlib import Path
 import sys
 from datetime import datetime
-from typing import Dict, List, Tuple
+from typing import Dict, List
 
 from vnpy.event import EventEngine
 from vnpy.trader.constant import (
@@ -31,13 +31,11 @@ from vnpy.trader.event import EVENT_TIMER
 from ..api import (
     MdApi,
     TdApi,
-    THOST_FTDC_OAS_Submitted,
-    THOST_FTDC_OAS_Accepted,
-    THOST_FTDC_OAS_Rejected,
     THOST_FTDC_OST_NoTradeQueueing,
     THOST_FTDC_OST_PartTradedQueueing,
     THOST_FTDC_OST_AllTraded,
     THOST_FTDC_OST_Canceled,
+    THOST_FTDC_OST_Unknown,
     THOST_FTDC_D_Buy,
     THOST_FTDC_D_Sell,
     THOST_FTDC_PD_Long,
@@ -67,13 +65,11 @@ from ..api import (
 
 # 委托状态映射
 STATUS_MINI2VT: Dict[str, Status] = {
-    THOST_FTDC_OAS_Submitted: Status.SUBMITTING,
-    THOST_FTDC_OAS_Accepted: Status.SUBMITTING,
-    THOST_FTDC_OAS_Rejected: Status.REJECTED,
     THOST_FTDC_OST_NoTradeQueueing: Status.NOTTRADED,
     THOST_FTDC_OST_PartTradedQueueing: Status.PARTTRADED,
     THOST_FTDC_OST_AllTraded: Status.ALLTRADED,
-    THOST_FTDC_OST_Canceled: Status.CANCELLED
+    THOST_FTDC_OST_Canceled: Status.CANCELLED,
+    THOST_FTDC_OST_Unknown: Status.SUBMITTING
 }
 
 # 多空方向映射
@@ -86,13 +82,13 @@ DIRECTION_MINI2VT[THOST_FTDC_PD_Long] = Direction.LONG
 DIRECTION_MINI2VT[THOST_FTDC_PD_Short] = Direction.SHORT
 
 # 委托类型映射
-ORDERTYPE_VT2MINI: Dict[OrderType, Tuple] = {
+ORDERTYPE_VT2MINI: Dict[OrderType, tuple] = {
     OrderType.LIMIT: (THOST_FTDC_OPT_LimitPrice, THOST_FTDC_TC_GFD, THOST_FTDC_VC_AV),
     OrderType.MARKET: (THOST_FTDC_OPT_AnyPrice, THOST_FTDC_TC_GFD, THOST_FTDC_VC_AV),
     OrderType.FAK: (THOST_FTDC_OPT_LimitPrice, THOST_FTDC_TC_IOC, THOST_FTDC_VC_AV),
     OrderType.FOK: (THOST_FTDC_OPT_LimitPrice, THOST_FTDC_TC_IOC, THOST_FTDC_VC_CV),
 }
-ORDERTYPE_MINI2VT = {v: k for k, v in ORDERTYPE_VT2MINI.items()}
+ORDERTYPE_MINI2VT: Dict[tuple, OrderType] = {v: k for k, v in ORDERTYPE_VT2MINI.items()}
 
 # 开平方向映射
 OFFSET_VT2MINI: Dict[Offset, str] = {
@@ -109,7 +105,8 @@ EXCHANGE_MINI2VT: Dict[str, Exchange] = {
     "SHFE": Exchange.SHFE,
     "CZCE": Exchange.CZCE,
     "DCE": Exchange.DCE,
-    "INE": Exchange.INE
+    "INE": Exchange.INE,
+    "GFEX": Exchange.GFEX
 }
 
 # 产品类型映射
@@ -170,9 +167,18 @@ class MiniGateway(BaseGateway):
         appid: str = setting["产品名称"]
         auth_code: str = setting["授权编码"]
 
-        if not td_address.startswith("tcp://"):
+        if (
+            (not td_address.startswith("tcp://"))
+            and (not td_address.startswith("ssl://"))
+            and (not td_address.startswith("socks"))
+        ):
             td_address = "tcp://" + td_address
-        if not md_address.startswith("tcp://"):
+
+        if (
+            (not md_address.startswith("tcp://"))
+            and (not md_address.startswith("ssl://"))
+            and (not md_address.startswith("socks"))
+        ):
             md_address = "tcp://" + md_address
 
         self.td_api.connect(td_address, userid, password, brokerid, auth_code, appid)
@@ -353,7 +359,7 @@ class MiniMdApi(MdApi):
 
         self.gateway.on_tick(tick)
 
-    def connect(self, address: str, userid: str, password: str, brokerid: int) -> None:
+    def connect(self, address: str, userid: str, password: str, brokerid: str) -> None:
         """连接服务器"""
         self.userid = userid
         self.password = password
@@ -423,7 +429,6 @@ class MiniTdApi(TdApi):
 
         self.frontid: int = 0
         self.sessionid: int = 0
-
         self.order_data: List[dict] = []
         self.trade_data: List[dict] = []
         self.positions: Dict[str, PositionData] = {}
@@ -525,7 +530,7 @@ class MiniTdApi(TdApi):
                 self.positions[key] = position
 
             # 对于上期所昨仓需要特殊处理
-            if position.exchange == Exchange.SHFE:
+            if position.exchange in {Exchange.SHFE, Exchange.INE}:
                 if data["YdPosition"] and not data["TodayPosition"]:
                     position.yd_volume = data["Position"]
             # 对于其他交易所昨仓的计算
@@ -565,7 +570,6 @@ class MiniTdApi(TdApi):
             gateway_name=self.gateway_name
         )
         account.available = data["Available"]
-        account.balance = account.available + account.frozen
 
         self.gateway.on_account(account)
 
@@ -595,6 +599,7 @@ class MiniTdApi(TdApi):
                 contract.option_type = OPTIONTYPE_MINI2VT.get(data["OptionsType"], None)
                 contract.option_strike = data["StrikePrice"]
                 contract.option_index = str(data["StrikePrice"])
+                contract.option_listed = datetime.strptime(data["OpenDate"], "%Y%m%d")
                 contract.option_expiry = datetime.strptime(data["ExpireDate"], "%Y%m%d")
 
             self.gateway.on_contract(contract)
@@ -641,12 +646,16 @@ class MiniTdApi(TdApi):
         dt: datetime = dt.replace(tzinfo=CHINA_TZ)
 
         tp: tuple = (data["OrderPriceType"], data["TimeCondition"], data["VolumeCondition"])
+        order_type: OrderType = ORDERTYPE_MINI2VT.get(tp, None)
+        if not order_type:
+            self.gateway.write_log(f"收到不支持的委托类型，委托号：{orderid}")
+            return
 
         order: OrderData = OrderData(
             symbol=symbol,
             exchange=contract.exchange,
             orderid=orderid,
-            type=ORDERTYPE_MINI2VT[tp],
+            type=order_type,
             direction=DIRECTION_MINI2VT[data["Direction"]],
             offset=OFFSET_MINI2VT[data["CombOffsetFlag"]],
             price=data["LimitPrice"],
@@ -694,7 +703,7 @@ class MiniTdApi(TdApi):
         address: str,
         userid: str,
         password: str,
-        brokerid: int,
+        brokerid: str,
         auth_code: str,
         appid: str
     ) -> None:
@@ -783,7 +792,10 @@ class MiniTdApi(TdApi):
         }
 
         self.reqid += 1
-        self.reqOrderInsert(mini_req, self.reqid)
+        n: int = self.reqOrderInsert(mini_req, self.reqid)
+        if n:
+            self.gateway.write_log(f"委托请求发送失败，错误代码：{n}")
+            return ""
 
         orderid: str = f"{self.frontid}_{self.sessionid}_{self.order_ref}"
         order: OrderData = req.create_order_data(orderid, self.gateway_name)
